@@ -328,10 +328,7 @@ class CLIParser:
                 action="store_true",
                 required=False,
                 help=(
-                    "select objects from the list of matches and show their details"
-                    " (for Objects, Worker Pools, Compute Requirement Templates,"
-                    " Compute Source Templates, Keyrings, Machine Image Families,"
-                    " Namespace Storage Configurations)"
+                    "select items from the list of matches and show their full details"
                 ),
             )
             parser.add_argument(
@@ -411,6 +408,12 @@ class CLIParser:
                 required=False,
                 help="list Namespace Storage Configurations",
             )
+            parser.add_argument(
+                "--instances",
+                action="store_true",
+                required=False,
+                help="list compute instances",
+            )
 
         if "upload" in sys.argv[0]:
             parser.add_argument(
@@ -457,7 +460,8 @@ class CLIParser:
             )
 
         if any(
-            module in sys.argv[0] for module in ["submit", "provision", "instantiate"]
+            module in sys.argv[0]
+            for module in ["submit", "provision", "instantiate", "create"]
         ):
             parser.add_argument(
                 "--dry-run",
@@ -495,7 +499,7 @@ class CLIParser:
 
         if any(
             module in sys.argv[0]
-            for module in ["submit", "provision", "instantiate", "create"]
+            for module in ["submit", "provision", "instantiate", "create", "remove"]
         ):
             parser.add_argument(
                 "--jsonnet-dry-run",
@@ -870,6 +874,10 @@ class CLIParser:
     def namespaces(self) -> Optional[bool]:
         return self.args.namespaces
 
+    @property
+    def instances(self) -> Optional[bool]:
+        return self.args.instances
+
     @property
     def show_keyring_passwords(self) -> Optional[bool]:
         return self.args.show_keyring_passwords
