@@ -26,6 +26,7 @@ from yellowdog_client.model import (
     ComputeRequirementTemplateUsage,
     ComputeSourceTemplateSummary,
     ConfiguredWorkerPool,
+    Instance,
     KeyringSummary,
     MachineImageFamilySummary,
     NodeStatus,
@@ -68,13 +69,17 @@ class PrintLogHighlighter(RegexHighlighter):
         r"(?P<date_time>[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]"
         r" [0-9][0-9]:[0-9][0-9]:[0-9][0-9])",
         r"(?P<quoted>'[a-zA-Z0-9-._=;:\/\\\[\]{}+#@$£%\^&\*\(\)~`<>?]*')",
+        r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9abcdef-]*)",
+        r"(?P<url>(https?):((//)|(\\\\))+[\w\d:#@%/;$()~_?\+-=\\\.&]*)",
     ]
 
 
 pyexamples_theme = Theme(
     {
-        "pyexamples.date_time": "blue",
+        "pyexamples.date_time": "bold blue",
         "pyexamples.quoted": "bold green",
+        "pyexamples.url": "bold magenta",
+        "pyexamples.ydid": "bold green",
     }
 )
 
@@ -127,7 +132,14 @@ def print_error(error_obj: ErrorObject):
     """
     Print an error message to stderr.
     """
-    CONSOLE_ERR.print(print_string(f"Error: {error_obj}"), style="red")
+    CONSOLE_ERR.print(print_string(f"Error: {error_obj}"), style="bold red")
+
+
+def print_warning(warning: str):
+    """
+    Print a warning.
+    """
+    CONSOLE.print(print_string(f"Warning: {warning}"), style="red")
 
 
 TYPE_MAP = {
@@ -154,6 +166,10 @@ def get_type_name(obj: Item) -> str:
         # Special case
         return "Namespace Storage Configuration"
 
+    if type(obj).__name__.endswith("Instance"):
+        # Special case
+        return "Instance"
+
     return TYPE_MAP.get(type(obj), "")
 
 
@@ -401,6 +417,42 @@ def image_family_table(
     return headers, table
 
 
+def object_path_table(
+    object_paths: List[ObjectPath],
+) -> (List[str], List[str]):
+    headers = ["#", "Name"]
+    table = []
+    for index, object_path in enumerate(object_paths):
+        table.append([index + 1, object_path.name])
+    return headers, table
+
+
+def instances_table(
+    instances: List[Instance],
+) -> (List[str], List[str]):
+    headers = [
+        "#",
+        "Type",
+        "Provider",
+        "Instance Type",
+        "Private IP",
+        "Public IP",
+    ]
+    table = []
+    for index, instance in enumerate(instances):
+        table.append(
+            [
+                index + 1,
+                instance.type.split(".")[-1],
+                instance.provider,
+                instance.instanceType,
+                instance.privateIpAddress,
+                instance.publicIpAddress,
+            ]
+        )
+    return headers, table
+
+
 def print_numbered_object_list(
     client: PlatformClient,
     objects: List[Item],
@@ -441,6 +493,10 @@ def print_numbered_object_list(
         headers, table = keyring_table(objects)
     elif isinstance(objects[0], MachineImageFamilySummary):
         headers, table = image_family_table(objects)
+    elif isinstance(objects[0], ObjectPath):
+        headers, table = object_path_table(objects)
+    elif isinstance(objects[0], Instance):
+        headers, table = instances_table(objects)
     else:
         table = []
         for index, obj in enumerate(objects):
@@ -484,8 +540,15 @@ def print_numbered_strings(objects: List[str], override_quiet: bool = False):
 def sorted_objects(objects: List[Item], reverse: bool = False) -> List[Item]:
     """
     Sort objects by their 'name' property, or 'namespace' in the case of
-    Namespace Storage Configurations.
+    Namespace Storage Configurations, or 'instanceType' in the case of
+    Instances.
     """
+    if len(objects) == 0:
+        return objects
+
+    if isinstance(objects[0], Instance):
+        return sorted(objects, key=lambda x: x.instanceType, reverse=reverse)
+
     try:
         return sorted(objects, key=lambda x: x.name, reverse=reverse)
     except:
@@ -515,9 +578,9 @@ def print_json(
     if drop_first_line:
         json_string = "\n".join(json_string.splitlines()[1:])
     if with_final_comma:
-        CONSOLE_JSON.print(json_string, end=",\n")
+        CONSOLE_JSON.print(json_string, end=",\n", soft_wrap=True)
     else:
-        CONSOLE_JSON.print(json_string)
+        CONSOLE_JSON.print(json_string, soft_wrap=True)
 
 
 def print_yd_object(
@@ -607,7 +670,7 @@ def print_compute_template_test_result(result: ComputeRequirementTemplateTestRes
     sources: List[BestComputeSourceReportSource] = report.sources
     source_table = [
         [
-            "",
+            "#",
             "Rank",
             "Provider",
             "Type",
@@ -629,7 +692,10 @@ def print_compute_template_test_result(result: ComputeRequirementTemplateTestRes
             ]
         )
     print()
-    print(tabulate(source_table, headers="firstrow", tablefmt="simple_outline"))
+    CONSOLE.print(
+        indent(tabulate(source_table, headers="firstrow", tablefmt="simple_outline")),
+        style=TABLE_OUTPUT_STYLE,
+    )
     print()
 
 
@@ -651,7 +717,7 @@ def print_batch_upload_files(upload_batch_builder: UploadBatchBuilder):
     if ARGS_PARSER.quiet:
         return
 
-    headers = ["Item", "Source Object", "->", "Target Object"]
+    headers = ["#", "Source Object", "Target Object"]
     table = []
     # Yes, I know I shouldn't be accessing '_source_file_entries'
     for index, file_entry in enumerate(upload_batch_builder._source_file_entries):
@@ -659,12 +725,15 @@ def print_batch_upload_files(upload_batch_builder: UploadBatchBuilder):
             [
                 index + 1,
                 file_entry.source_file_path,
-                "->",
                 f"{upload_batch_builder.namespace}::{file_entry.default_object_name}",
             ]
         )
     print()
-    print(indent(tabulate(table, headers=headers, tablefmt="simple"), indent_width=4))
+    print(
+        indent(
+            tabulate(table, headers=headers, tablefmt="simple_outline"), indent_width=4
+        )
+    )
     print()
 
 
@@ -677,7 +746,7 @@ def print_batch_download_files(
     if ARGS_PARSER.quiet:
         return
 
-    headers = ["Item", "Source Object", "->", "Target Object"]
+    headers = ["#", "Source Object", "Target Object"]
     directory_separator = "\\" if os_name == "nt" else "/"
     table = []
     # Yes, I know I shouldn't be accessing '_source_object_entries'
@@ -692,7 +761,6 @@ def print_batch_download_files(
             [
                 index + 1,
                 object_source,
-                "->",
                 relpath(
                     f"{download_batch_builder.destination_folder}"
                     f"{directory_separator}"
@@ -701,5 +769,10 @@ def print_batch_download_files(
             ]
         )
     print()
-    print(indent(tabulate(table, headers=headers, tablefmt="simple"), indent_width=4))
+    CONSOLE.print(
+        indent(
+            tabulate(table, headers=headers, tablefmt="simple_outline"), indent_width=4
+        ),
+        style=TABLE_OUTPUT_STYLE,
+    )
     print()
